<?php

App::uses('AppHelper', 'View/Helper');

class BreadcrumbHelper extends AppHelper {

	public $helpers = array('Html');

	public $settings = array(
		'crumbsWrapTag' => null,
		'crumbsWrapAttributes' => array(),
		'crumbWrapTag' => 'li',
		'crumbWrapAttributes' => array(),
		'separator' => '<span class="breadcrumbs__sep"><i class="fa fa-angle-right"></i></span>'
	);

	/**
	 * Returns the back link if set.
	 * @param  array $breadcrumbs Full breadcrumbs variable set by the plugin
	 * @return string|void        Back link
	 */
	public function backLink($breadcrumbs) {
		if (!empty($breadcrumbs['backLink']['text']) && !empty($breadcrumbs['backLink']['url'])) {
			return $this->Html->link(
				$breadcrumbs['backLink']['text'],
				$breadcrumbs['backLink']['url'],
				!empty($breadcrumbs['backLink']['options']) ? $breadcrumbs['backLink']['options'] : array()
			);
		}
		return;
	}

	/**
	 * Returns the breadcrumb.
	 * @param  array $breadcrumbs Full breadcrumbs variable set by the plugin
	 * @return string|void        Fully marked up breadcrumb
	 */
	public function crumbs($breadcrumbs) {
		$crumbs = array();
		foreach ($breadcrumbs['crumbs'] as $crumb) {
			$crumbs[] = $this->Html->tag(
				$this->settings['crumbWrapTag'],
				$this->crumb($crumb),
				$this->settings['crumbWrapAttributes']
			);
		}
		if (!empty($this->settings['crumbsWrapTag'])) {
			return $this->Html->tag(
				$this->settings['crumbsWrapTag'],
				implode($this->separator(), $crumbs),
				$this->settings['crumbsWrapAttributes']
			);
		} else {
			return implode($this->separator(), $crumbs);
		}
	}

	/**
	 * Returns a breadcrumb.
	 * @param  array $breadcrumbs Breadcrumb array
	 * @return string|void
	 */
	public function crumb($crumb) {
		if (!empty($crumb['url'])) {
			return $this->Html->link(
				$crumb['text'],
				$crumb['url'],
				!empty($crumb['options']) ? $crumb['options'] : array()
			);
		} else {
			return $crumb['text'];
		}
	}

	/**
	 * Returns the separator.
	 * @return string Separator
	 */
	public function separator() {
		return $this->settings['separator'];
	}

}
